
Configuration File Reference
=================================
The SMRF configuration file is described in detail below. This information is
all based on the CoreConfig file stored under framework.

.. include:: ./auto_config.rst
